;
;====================================================
;
;   Demo908AP64.asm    Demo908AP64 Board Test Program  
;                                 
;   Version:           1.0   Released 5/20/2004
;   Author:            Gary Karnes 
;   Purpose:           Define Registers  
; (C) Copyright 2004   All rights reserved.
;====================================================
;
; Note: Input clock is set at 4.9152 Mhz? at 3.3v
;       Bus clock is input clock/4
; 
;            XDEF IRQ
            XDEF Entry
; Definitions
Reg_Start:  equ    $0000   ; Start of Registers
Reg_En:     equ    $005F   ; End of Registers
Ram_Start:  equ    $0060   ; Start of Ram
Ram_End:    equ    $085F   ; End of Ram
Flash_Start:  equ    $0860  ; Flash Start
Flash_End:    equ    $FBFF  ; Flash End
initStack:  EQU    $085F   ; stack default 

; Register equates...
            include  AP64_Regs.asm


; data equates....

CR:		EQU	$0d		; hex carriage return character
LF:		EQU	$0A		; hex line feed character
NUL:		EQU	$00		; ascii null character, end of string
PLLON:      equ   5           ; PLL bit
LOCK:       equ   6
BCS:        equ   4
AUTO:       equ   7

TC:         equ   6           ; transmitter empty
SCTE:       equ   7           ; transmitt buffer empty

; Interrupt vectors
;IRQ:            equ     $fe27           ; Irq interrupt vector


;MyStack:	SECTION	; stack default area = $200 - 23F.


; Data space for direct addressing mode...
;MyData1:     SECTION SHORT
            org  $80
Tmp:		DS.B	1	; temp use register
Tmp1:		DS.B	1	; temp use register
counter:    DS.B  1	; temp use counter

; Data space for extended addressing modes..
;MyData2:	SECTION

Tmpl:		DS.B	1	; temp use register

; Start rom space ...
;MyCode:     SECTION
            org  $8000
;             org  $C000
;             org   $0060     ; start of ram
; constants and text strings here...
             jmp  Entry

;
; Start program here...
Entry:
	LDHX   #initStack   ; initialize Stack
      TXS
	LDA	#$4B		; Set configuration registers
	STA	CONFIG1	; Stop on, COP off, LVI = 5V
;	LDA	#$01		; 
      LDA	#$11		; Crystal , internal data bus
	STA	CONFIG2	; SCI Baud = I clk (2.4576Mhz)
	LDA	#$01		; baud rate /2 configure serial port, 9600, 8, n, 1
	STA	SCBR
;      jsr   H08PLL      ; set up PLL & baud rate for 8mhz & 9600

	LDA	#$44
	STA	SCC1
	LDA	#$0C
	STA	SCC2
	CLR	SCC3
;        CLI
	
	nop
Main:
        

        LDHX	#MENU   	; Point to Menu
        JSR	     Sci1Strp	; send main menu string

;        jsr      Sci1Str1     ; send string
;        fdb      MENU


        
	  JSR	   INPUT   	; Get menu choice
	  JSR	   OUTPUT	; echo choice


        cmp     #$31
        bne     Nx04
        jsr     RZ1_Tst        ; do Irda Test
        jmp     Main



Nx04:
       
        cmp     #$32            ; choice = 1?
        beq     I_OTst
        cmp     #$33            ; choice = 1?
        beq     PushTst


        cmp     #$34
        bne     Nx03
        jsr     Pot_Tst        ; do Irda Test
        jmp     Main


Nx03

        cmp     #$35
        bne     Nx01
        jsr     Irda_Tst        ; do Irda Test
        jmp     Main

Nx01:

       cmp     #$36
        bne     Nx02
        jsr     LEDS_Tst        ; do Irda Test
        jmp     Main

Nx02:




        jmp     Main

; echo characters , quit if space bar is pressed
ComTst:
        LDHX    #MSG_ECHO       ; load ehco test message
        jsr     Sci1Strp        ; send message
ECHOL01:
        jsr     INPUT           ; read a character
        cmp     #$20            ; space?
        beq     Main            ; return to main menu
        cmp     #$0d            ; car ret?
        bne     ECHON01
        lda     #$0a            ; send line feed
ECHON01:
        jsr     OUTPUT          ; echo char
        jmp     ECHOL01         ; repeat


; I/O Test
I_OTst:
        ldhx    #MSG_IO         ; Port test message
        jsr     Sci1Strp        ; 


; Setup Ports

        mov     #$CF,DDRA        ; Setup Port A 
        mov     #$f3,DDRB        ; Setup Port B 
        mov     #$3f,DDRC        ; Setup Port C PTC6,7 did not use
        mov     #$ff,DDRD        ; Setup Port D  

        LDA     SCDR		          ; Clear any byte

IOLoop:        
        lda     #$55              ; pattern
        sta     PTA               ; 
        sta     PTB               ; 
        sta     PTC               ; 
        sta     PTD               ;


        lda     #$AA              ; pattern
        sta     PTA               ; 
        sta     PTB               ; 
        sta     PTC               ; 
        sta     PTD               ;

; Poll receiver for any data in...

	 lda	SCS1		; read status
       bit	#$20		; test if receive rdy
       beq	IOLoop	; 

       
        jmp    Main 

; Push Button Test
PushTst:
           mov     #$fc,DDRD       ; Set push buttons as input  
           lda     PTD
           and     #$03            ; get push buttons
           cmpa    #$03            ; verify high
           bne     Failed

           ldhx    #MSG_SW1        ; Press SW1
           jsr     Sci1Strp        ; 
PushL1:
           lda     PTD
           and     #$01            ; get push buttons
           bne     PushL1          ; wait for SW1 to be pressed


           ldhx    #MSG_SW2        ; Press SW1
           jsr     Sci1Strp        ; 
PushL2:
           lda     PTD
           and     #$02            ; get push buttons
           bne     PushL2          ; wait for SW1 to be pressed





           jmp    Main
;
; Report Failed
Failed:
          ldhx    #MSG_Failed        ; report failed
          jsr     Sci1Strp           ; 
          jsr     INPUT              ; wait for input

           jmp    Main
;
; LEDS Test
LEDS_Tst
          mov     #$ff,DDRB         ; turn on LED1

          ldhx    #MSG_LED1         ; Verify LED1 is on
          jsr     Sci1Strp          ;  
          mov     #$ef,PTB          ; turn on LED1
          jsr     INPUT             ; wait for operator
          
          ldhx    #MSG_LED2         ; Verify LED1 is on
          jsr     Sci1Strp          ; 
          mov     #$df,PTB          ; turn on LED2
          jsr     INPUT             ; wait for operator
          

          jmp    Main
;
; Pot Test
Pot_Tst:
           mov    #$24,ADSCR        ; turn on A/D
           ldhx    #MSG_Pot1         ; Verify Pot
           jsr     Sci1Strp          ; 
Pot_Lp1: 
           lda     ADRL0             ; get results
           cmp     #$10
           bhs     Pot_Lp1           ; repeat until correct

           ldhx    #MSG_Pot1         ; Verify Pot
           jsr     Sci1Strp          ; 
Pot_Lp2: 
           lda     ADRL0             ; get results
           cmp     #$f0
           bls     Pot_Lp2           ; repeat until correct
           jmp    Main
;
;
RZ1_Tst:

            mov    #$25,ADSCR        ; turn on A/D ch 5
           ldhx    #MSG_RZ1L         ; Verify Pot
           jsr     Sci1Strp         ; 
RZ1_Lp1: 
           lda     ADRL0            ; get results
           cmp     #$38
           bhs     RZ1_Lp1          ; repeat until correct

           ldhx    #MSG_RZ1D        ; Verify Pot
           jsr     Sci1Strp         ; 
RZ1_Lp2: 
           lda     ADRL0            ; get results
           cmp     #$d8
           bls     RZ1_Lp2          ; repeat until correct

           jmp    Main


;
; Input a character from input device
INPUT: 
        jsr     Receive         ; poll for char
        bcc     INPUT           ; repeat until char is received
        rts
; Poll receiver for any data in...
Receive:
	LDA	SCS1		; read status
	BIT	#$20		; test if receive rdy
	BNE	Receive1	; if true, get byte
	CLC			; clear recv flag
	RTS
Receive1:
	LDA	SCDR		; READ byte
	SEC			; set recv flag
	RTS


; OUTPUT a byte....
OUTPUT:
;	PSHA			; Temp Save byte
OUTPUT1:
;	LDA	SCS1		; read status
      brclr  TC,SCS1,OUTPUT1  ; wait for x-trans to empty 
;	BPL	OUTPUT1	; loop for ready to send
;	PULA			; get data back
	STA	SCDR		; send byte
OUTPUT2:
      brclr  TC,SCS1,OUTPUT2  ; wait for x-trans to empty

	RTS
;     
;
; Ports Test
;PORTTST:
;          lda     #$ff           
;          sta     DDRA            ; Port A all outputs
;          sta     DDRB            ; Port B all Outputs
;          sta     DDRC            ; Port C all outputs
;          sta     DDRD            ; Port D all outputs 
;          clra                    ; clear acc a
;PORTTL1:
;          sta     PTA             ; store in Port A
;          sta     PTB             ; store in Port B
;          sta     PTC             ; store in Port C
;          sta     PTD             ; store in Port D
;          inca                    ; increment acc A
;          bne     PORTTL1         ; repeat until done     
;          rts     
;
;
; Hex Input routines
;
; convert acc a to a hex value
HEXCON:
          sub     #$30            ; remove base number
          cmp     #$0a            ; if 0-9 then end
          blo     HEXI01 
          sub     #$07            ; convert A - F
          and     #$0f            ; remove upper case
HEXI01:
          rts
;
;
; Hex Output Routines
;
; Output right four bits of acc A as a hex ascii value
; send to com port
HEXOUT:
          and    #$0f            ; mask off bits
          cmp    #$09            ; number?
          bhi    HEXOUT01           ; a - f?
          add    #$30            ; add offset
          jsr    OUTPUT          ; send to output
          rts
HEXOUT01:
          add    #$37            ; a - f to ascii
          jsr    OUTPUT
          rts          
;
          include  AP64_Mes.asm   ; AP64 Messages
          include  AP64_PLL.asm   ; PLL Control
          include  AP64_Del.asm   ; Delay Routines
          include  AP64_Str.asm   ; String Output
          include  IrdaTst.asm    ; Irda Test
;          

; set reset vector
         org     $fffe 
         DC.W    Entry

         END            



