;
; =============================================================
;
;   IrdaEcho.asm    Axiom Driver for the Motorola Hc08 
;                                 
;   Version:        1.0   Released 05/27/2004
;   Author:         Spencer Ruggles , Axiom Mfg.
;   Compiler:       MCUez08
;       
;   Platform:       Axiom MC68HC08AP64
;   Purpose:        IrDA Test 
; 
; ===============================================================
;
;  Irda Echo Test
;  It requires IrdaEcho.s19 program to be running on 
;  another board for eching characters.
;  Procedure:  Send $00, $55, $AA, $FF
;	       Receive $0D
;	       Output receive char to screen and loop

	XDEF Entry

; Register Equates

REGBS:	       equ $00		; set register base
;SCC1:	       equ $13		; SCI Control Register 1
;SCC2:	       equ $14		; SCI Control Regitster 2
;SCS1:	       equ $16		; SCI Status Register 1
;SCDR:	       equ $18		; SCI Data Register
;SCBR:	       equ $19		; SCI Baud Rate Register
;CONFIG2:        equ     $1D     ; Configuration Register
;CONFIG1:        equ     $1F     ; Configuration Register
;IRSCC1:	       equ $40		; IRSCI Control Register 1
;IRSCC2:	       EQU $41		; IRSCI Control Register 2
;IRSCC3:	       EQU $42		; IRSCI Control Register 3
;IRSCS1:	      EQU $43		; IRSCI Status Register 1
;IRSCS2:	      EQU $44		; IRSCI Status Register 2
;IRSCDR:	      EQU $45		; IRSCI Data Register
;IRSCBR:	     EQU $46		; IRSCI Baud Rate Register
;IRSCIRCR:	EQU $47	; IRSCI Intrared Control Register 
SCTE:             equ    7                     ; transmit data transfered to x-mit
TC:                   equ   6                     ; no transmittion in progress
SCRF:             equ  5                       ; 1 receive data available


; data equates....

CR:		EQU $0D		; hex carriage return character
LF:		EQU $0A		; hex line feed character
NUL:		EQU $00		; ascii null character, end of string

; Register equates...
            include  AP64_Regs.asm

; Data space for direct addressing mode...
;	ORG  $60

;Tmp:		DS.B 1		; temp use register
;Tmp1:		DS.B 1		; temp use register
;counter:	DS.B 1		; temp use counter


;========== Program starts here ==========
;	org $0860		; program start location - Flash
;	org $0060		; program start location - RAM
      org $8000 
Entry:
             
Irda_Tst:

	ldhx #$085F		; intitalize stack pointer
	txs			; xfr H:X to SP

                    mov   #$4b,CONFIG1         ; cop off
                    mov   #$11,CONFIG2         ;

; Configure SCI comm

	mov #$40, SCC1		; en SCI, 8-bit, no pty
	mov #$0C, SCC2		; TX en, RX en
	mov #$03, SCBR		; 9600 bps
	

; Configure IrDA comm

	mov #$40, IRSCC1	      ; en IRSCI, 8-bit, no pty
	mov #$0C, IRSCC2	      ; TX en, RX en
	mov #$05, IRSCBR	      ; 9600 bps, CGMXCLK sel
	mov #$01, IRSCIRCR     ; en IR encode/decode sub-module
	
;	ldhx #CRLF
;	jsr Send_MSG		; new line 
;	ldhx #MIrda		; Irda Test
;	jsr Send_MSG
	

;	ldhx #MRemote		; Remote Echo must be running
;	jsr Send_MSG
	

;	ldhx #CRLF
;	jsr Send_MSG		; new line 	lda IRSCDR		; clear IR data register
;
; Setup LEDS
                   mov    #$30,DDRB                ; enable LEDS
                   mov    #$30,PTB                    ;  turn LEDS off     
; IR Start transmitting 	

Irda_rs:

; Wait for character and compare to $5A             
IrdaW00:
	lda IRSCDR		; read any data
                    mov   #$10,PTB                               ; turn LED2 On
IrdaW01:
	brclr 5,IRSCS1,IrdaW01	; wait for charactor
                   lda IRSCDR		; read any data
	cmp   #$5A		; compare data
	bne   IrdaW01		; repeat if not correct
  
; Write character back
                    jsr        DEL100MS                          ; Delay
IrdaSA5:
                    mov   #$20,PTB                               ; turn LED1 On
;	brclr 6,IRSCS1,IrdaW55	; loop if TC flag clear
                    lda    IRSCS1                                   ; read status
	lda #$A5            		; load pattern
	sta IRSCDR		; send data  
	jsr DELAY50M		; Delay  
;
                   bra IrdaW00                                      ; Start over

IrdaWAA
	brclr 6,IRSCS1,IrdaWAA	; loop if TC flag clear
;	lda IRSCS1		; get IrDA status
;	bpl IrdaWAA		; loop until tx empty 
	lda #$AA		; send pattern
	sta IRSCDR		; send data  
;	jsr Delay		; wait  

IrdaWFF:
	brclr 6,IRSCS1,IrdaWFF	; loop if TC flag clear
;	lda IRSCS1		; get IrDA status
;	bpl IrdaWFF		; loop until tx empty 
	lda #$FF		; send pattern
	sta IRSCDR		; send data  


Irda_L1:
	lda IRSCDR		; clr data register
	brclr 5,IRSCS1,Irda_L1	; loop if SCRF flag set
;	lda IRSCS1		; get IrDA status
;	bit #$20		; ch for RX data 
;	beq Irda_L1		; loop until RX data present
	lda IRSCDR		; get tx data
	cmp #$0D		; verify response
	beq PASS		; passed message
	ldhx #MError		; get error message
	jsr Send_MSG		; report error
	bra Irda_rs		; try again

PASS:
	ldhx #CRLF		; new line
	jsr Send_MSG
	ldhx #MPassed		; report passed
	jsr Send_MSG

	bra Irda_rs		; repeat until RESET



;========== Sub-Routines ==========


; Output Messages

MIrda:
	DC	CR
	DC 	LF
	DC	"IrDA Test"
	DC	CR
     DC	LF
     DC	NUL			; end message string

MRemote:
	DC	CR
	DC	LF
	DC	"Remote Echo must be running"
	DC	CR
	DC	LF
	DC	NUL		; end message string

MPassed:
	DC	CR
	DC	LF
	DC	"Test Passed "
	DC	CR
	DC	LF
	DC	NUL		; end message string

MError:
	DC	CR
	DC	LF
	DC	"IrDA Error "
	DC	CR
	DC	LF
	DC	NUL		; end message string

CRLF:
	DC	CR
	DC	LF
	DC	NUL		; end message string 


;===== Delay Routine ======

Delay:

	psha			; save A
	lda #$50		; load outer loop count
Dly:
	ldx #$FF		; load inner loop count
Dly1:
	dbnzx Dly1		; loop until X = 0
	dbnza Dly		; loop until A = 0

	pula			; restore A
	rts			; return


; Transmit a byte....

Transmit:
	PSHA			; Temp Save byte

Transmit1:
	LDA SCS1		; read status
	BPL Transmit1		; loop for ready to send
	PULA			; get data back
	STA SCDR		; send byte
	RTS


; Transmit string...
Send_MSG:

Send_lp:
	LDA ,X			; get byte
	INCX			; bump pointer +1
	JSR Transmit		; send byte out
	CMP #NUL		; test for end
	BNE Send_lp   		; loop if more bytes
	RTS
                include    AP64_Del.asm        ; Delay Routines

;===== RESET Vector =====

	ORG  $FFFE
	DC.W Entry		; reset vector

END:	
